@@ -119,10 +119,14 @@ public class AudioUtil {
 
     @SuppressLint("NewApi")
     public static void prepareCacheFolder(Context context) {
-        if (LibVlcUtil.isFroyoOrLater() && AndroidDevices.hasExternalStorage() && context.getExternalCacheDir() != null)
-            CACHE_DIR = context.getExternalCacheDir().getPath();
-        else
+        try {
+            if (LibVlcUtil.isFroyoOrLater() && AndroidDevices.hasExternalStorage() && context.getExternalCacheDir() != null)
+                CACHE_DIR = context.getExternalCacheDir().getPath();
+            else
+                CACHE_DIR = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
+        } catch (Exception e) { // catch NPE thrown by getExternalCacheDir()
             CACHE_DIR = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
+        }
         ART_DIR = CACHE_DIR + "/art/";
         COVER_DIR = CACHE_DIR + "/covers/";
         PLAYLIST_DIR = CACHE_DIR + "/playlists/";
